@@ -1,17 +1,22 @@
-
+#' @importFrom stringi stri_trans_general
 #' @export
-
 makeSASNames <- function(names, nchar=8, maxPasses=10, quiet=FALSE)
   {
     ## This function takes a vector of potential SAS dataset or
     ## variable names and converts them into *unique* 8-character
     ## names.
 
+    #!# # Step -2: convert to ASCII
+    #!# names <- stri_trans_general(names, "Any-Latin; Latin-ASCII")
+
+    #!# # Step -1: strip all whitespace
+    #!# names <- gsub("[[:space:]]+", "", names)
+
     # Step 0: converce to uppercase
     names <- toupper(names)
     
     # Step 1: expand/truncate to 8 characters
-    tooLong <- nchar(names)>8
+    tooLong <- nchar(names, "bytes")>8
     if (any(tooLong))
       {
         shortNames <- substr(as.character(names), 1, nchar)
@@ -31,7 +36,7 @@ makeSASNames <- function(names, nchar=8, maxPasses=10, quiet=FALSE)
         passes <- passes+1
         dups <- duplicated(varNames)
         repeatCount <- table(varNames)-1
-        digitChars <- nchar(as.character(repeatCount))+1
+        digitChars <- nchar(as.character(repeatCount), "bytes")+1
         names(digitChars) <- names(repeatCount)
         newNames <- make.names(substr(varNames, 1, nchar-digitChars[varNames]), unique=TRUE)
         changed <- newNames != names
