@@ -1,7 +1,10 @@
 library(SASxport)
 Sys.setenv("TZ"="GMT")
 
+set.seed(42)
+
 # run the examples, comparing output
+example(Alfalfa)
 example(SASformat)
 example(lookup.xport)
 example(makeSASNames)
@@ -9,4 +12,3 @@ example(read.xport)
 example(toSAS)
 example(write.xport)
 
-
